@@ -579,56 +579,6 @@ eel_point_in_widget (GtkWidget *widget,
 	return eel_point_in_allocation (&widget->allocation, x, y);
 }
 
-/**
- * eel_gtk_object_list_ref
- *
- * Ref all the objects in a list.
- * @list: GList of objects.
- **/
-GList *
-eel_gtk_object_list_ref (GList *list)
-{
-	g_list_foreach (list, (GFunc) g_object_ref, NULL);
-	return list;
-}
-
-/**
- * eel_gtk_object_list_unref
- *
- * Unref all the objects in a list.
- * @list: GList of objects.
- **/
-void
-eel_gtk_object_list_unref (GList *list)
-{
-	g_list_foreach (list, (GFunc) g_object_unref, NULL);
-}
-
-/**
- * eel_gtk_object_list_free
- *
- * Free a list of objects after unrefing them.
- * @list: GList of objects.
- **/
-void
-eel_gtk_object_list_free (GList *list)
-{
-	eel_gtk_object_list_unref (list);
-	g_list_free (list);
-}
-
-/**
- * eel_gtk_object_list_copy
- *
- * Copy the list of objects, ref'ing each one.
- * @list: GList of objects.
- **/
-GList *
-eel_gtk_object_list_copy (GList *list)
-{
-	return g_list_copy (eel_gtk_object_list_ref (list));
-}
-
 /**
  * eel_gtk_widget_set_shown
  *
@@ -837,61 +787,6 @@ eel_gtk_signal_connect_while_realized (GtkObject *object,
 						 name, callback, callback_data);
 }
 
-/**
- * eel_nullify_when_destroyed.
- *
- * Nulls out a saved reference to an object when the object gets destroyed.
- * @data: Address of the saved reference.
- **/
-
-void 
-eel_nullify_when_destroyed (gpointer data)
-{
-	GObject **object_reference;
-
-	object_reference = (GObject **)data;
-	if (*object_reference == NULL) {
-		/* the reference is  NULL, nothing to do. */
-		return;
-	}
-
-	g_assert (G_IS_OBJECT (*object_reference));
-
-	g_object_add_weak_pointer (*object_reference,
-				   (void*) object_reference);
-}
-
-/**
- * eel_nullify_cancel.
- *
- * Disconnects the signal used to make eel_nullify_when_destroyed.
- * Used when the saved reference is no longer needed, the structure it is in is
- * being destroyed, etc. Nulls out the refernce when done.
- * @data: Address of the saved reference.
- **/
-
-void 
-eel_nullify_cancel (gpointer data)
-{
-	GObject **object_reference;
-
-	object_reference = (GObject **)data;	
-	if (*object_reference == NULL) {
-		/* the object was already destroyed and the reference nulled out,
-		 * nothing to do.
-		 */
-		return;
-	}
-
-	g_assert (G_IS_OBJECT (*object_reference));
-
-	g_object_remove_weak_pointer (*object_reference,
-				      (void*) object_reference);
-	
-	*object_reference = NULL;
-}
-
-
 /**
  * eel_gtk_container_get_first_child.
  *
@@ -1170,3 +1065,100 @@ eel_gtk_widget_get_motion_event_location (GtkWidget *widget,
 {
 	eel_gtk_widget_get_button_event_location (widget, (const GdkEventButton *) event, x, y);
 }
+
+gboolean
+eel_gtk_tree_view_cell_is_completely_visible (GtkTreeView          *tree_view,
+					      GtkTreePath          *path,
+					      GtkTreeViewColumn    *column)
+{
+	GdkRectangle cell_rect, visible_rect;
+
+	gtk_tree_view_get_background_area (tree_view, path, column, &cell_rect);
+	gtk_tree_view_widget_to_tree_coords (tree_view, cell_rect.x, cell_rect.y,
+					     &cell_rect.x, &cell_rect.y);
+	gtk_tree_view_get_visible_rect (tree_view, &visible_rect);
+	return eel_gdk_rectangle_contains_rectangle (visible_rect, cell_rect);
+}
+
+gboolean
+eel_gtk_viewport_get_visible_rect (GtkViewport  *viewport, 
+				   GdkRectangle *rect)
+{
+	GdkRectangle viewport_rect;
+	GdkRectangle child_rect;
+	gboolean return_val;
+
+	g_return_val_if_fail (GTK_IS_VIEWPORT (viewport), FALSE);
+	g_return_val_if_fail (rect != NULL, FALSE);
+	
+	if (GTK_WIDGET_REALIZED (viewport)) {
+		viewport_rect.x = 0;
+		viewport_rect.y = 0;
+		gdk_drawable_get_size (viewport->view_window, 
+				       &viewport_rect.width, 
+				       &viewport_rect.height);
+		
+		gdk_window_get_position (viewport->bin_window,
+					 &child_rect.x,
+					 &child_rect.y);
+		gdk_drawable_get_size (viewport->bin_window,
+				       &child_rect.width,
+				       &child_rect.height);
+
+		return_val = gdk_rectangle_intersect (&viewport_rect, 
+						      &child_rect,
+						      rect);
+		rect->x -= child_rect.x;
+		rect->y -= child_rect.y;
+		
+		return return_val;
+	}
+	
+	rect->x = rect->y = rect->width = rect->height = 0;
+	return FALSE;
+}
+
+void
+eel_gtk_viewport_scroll_to_rect (GtkViewport  *viewport, 
+				 GdkRectangle *rect)
+{
+	GdkRectangle visible_rect;
+	int scroll_x;
+	int scroll_y;
+	GtkAdjustment *adjustment;
+
+	g_return_if_fail (GTK_IS_VIEWPORT (viewport));
+	g_return_if_fail (rect != NULL);
+
+	if (eel_gtk_viewport_get_visible_rect (viewport, &visible_rect)) {
+		scroll_x = -1;
+		scroll_y = -1;
+
+		if (rect->x + rect->width > visible_rect.x + visible_rect.width) {
+			scroll_x = rect->x - (visible_rect.width - rect->width);
+		}
+		if (rect->y + rect->height > visible_rect.y + visible_rect.height) {
+			scroll_y = rect->y - (visible_rect.height - rect->height);
+		}
+
+		if (rect->x < visible_rect.x) {
+			scroll_x = rect->x;
+		}
+
+		if (rect->y < visible_rect.y) {
+			scroll_y = rect->y;
+		}
+
+		adjustment = gtk_viewport_get_hadjustment (viewport);
+		if (adjustment && scroll_x != -1) {
+			eel_gtk_adjustment_set_value (adjustment,
+						      (double)scroll_x);
+		}
+
+		adjustment = gtk_viewport_get_vadjustment (viewport);
+		if (adjustment && scroll_y != -1) {
+			eel_gtk_adjustment_set_value (adjustment,
+						      (double)scroll_y);
+		}
+	}
+}
