@@ -23,7 +23,6 @@
 */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
 #include "eel-labeled-image.h"
 
 #include "eel-art-extensions.h"
@@ -154,21 +153,20 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
         g_object_class_install_property (
 		gobject_class,
 		PROP_PIXBUF,
-		g_param_spec_object ("pixbuf", _("pixbuf"), _("the image"),
+		g_param_spec_object ("pixbuf", NULL, NULL,
 				     GDK_TYPE_PIXBUF, G_PARAM_READWRITE));
 
         g_object_class_install_property (
 		gobject_class,
 		PROP_LABEL,
-		g_param_spec_string ("label", _("label"), _("the label"),
+		g_param_spec_string ("label", NULL, NULL,
 				     "", G_PARAM_READWRITE));
 
 
         g_object_class_install_property (
 		gobject_class,
 		PROP_LABEL_POSITION,
-		g_param_spec_enum ("label_position",
-				   _("position"), _("the label position"),
+		g_param_spec_enum ("label_position", NULL, NULL,
 				   GTK_TYPE_POSITION_TYPE,
 				   GTK_POS_BOTTOM,
 				   G_PARAM_READWRITE));
@@ -176,26 +174,20 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
         g_object_class_install_property (
 		gobject_class,
 		PROP_SHOW_LABEL,
-		g_param_spec_boolean ("show_label",
-				      _("label visible"),
-				      _("whether to show the label"),
+		g_param_spec_boolean ("show_label", NULL, NULL,
 				      TRUE, G_PARAM_READWRITE)); 
 				   
         g_object_class_install_property (
 		gobject_class,
 		PROP_SHOW_IMAGE,
-		g_param_spec_boolean ("show_image",
-				      _("image visible"),
-				      _("whether to show the image"),
+		g_param_spec_boolean ("show_image", NULL, NULL,
 				      TRUE, G_PARAM_READWRITE)); 
 				   
 
 	g_object_class_install_property (
 		gobject_class,
 		PROP_SPACING,
-		g_param_spec_uint ("spacing",
-				   _("Spacing"),
-				   _("The amount of space between the items."),
+		g_param_spec_uint ("spacing", NULL, NULL,
 				   0,
 				   G_MAXINT,
 				   DEFAULT_SPACING,
@@ -204,9 +196,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	g_object_class_install_property (
 		gobject_class,
 		PROP_X_PADDING,
-		g_param_spec_int ("x_padding",
-				  _("X padding"),
-				  _("the amount of horizontal padding space."),
+		g_param_spec_int ("x_padding", NULL, NULL,
 				  0,
 				  G_MAXINT,
 				  DEFAULT_X_PADDING,
@@ -215,9 +205,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	g_object_class_install_property (
 		gobject_class,
 		PROP_Y_PADDING,
-		g_param_spec_int ("y_padding",
-				  _("Y padding"),
-				  _("the amount of vertical padding space"),
+		g_param_spec_int ("y_padding", NULL, NULL,
 				  0,
 				  G_MAXINT,
 				  DEFAULT_Y_PADDING,
@@ -226,9 +214,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	g_object_class_install_property (
 		gobject_class,
 		PROP_X_ALIGNMENT,
-		g_param_spec_float ("x_alignment",
-				    _("Horizontal alignment"),
-				    _("Horizontal position of child in available space. 0.0 is left aligned, 1.0 is right aligned"),
+		g_param_spec_float ("x_alignment", NULL, NULL,
 				    0.0,
 				    1.0,
 				    DEFAULT_X_ALIGNMENT,
@@ -237,9 +223,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	g_object_class_install_property (
 		gobject_class,
 		PROP_Y_ALIGNMENT,
-		g_param_spec_float ("y_alignment",
-				    _("Vertical alignment"),
-				    _("Vertical position of child in available space. 0.0 is top aligned, 1.0 is bottom aligned"),
+		g_param_spec_float ("y_alignment", NULL, NULL,
 				    0.0,
 				    1.0,
 				    DEFAULT_Y_ALIGNMENT,
@@ -248,8 +232,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 	g_object_class_install_property (
 		gobject_class,
 		PROP_FILL,
-		g_param_spec_boolean ("fill", _("fill"),
-				      _("expand to fill allocation"),
+		g_param_spec_boolean ("fill", NULL, NULL,
 				      FALSE,
 				      G_PARAM_READWRITE));
 }
