@@ -28,16 +28,16 @@
 #include <config.h>
 #include "eel-preferences-box.h"
 
+#include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeselection.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkdialog.h>
+#include <gtk/gtkliststore.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkstock.h>
-#include <eel/eel-gtk-extensions.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktreeview.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 
@@ -359,14 +359,11 @@ eel_preferences_box_new (void)
 
 	preferences_box->details->category_view = GTK_TREE_VIEW (tree_view);
 
-	gtk_tree_view_insert_column_with_attributes (
-		preferences_box->details->category_view,
-		0,
-		_("preference group"),
-		gtk_cell_renderer_text_new (),
-		"text",
-		CATEGORY_COLUMN,
-		NULL);
+	gtk_tree_view_insert_column_with_attributes
+		(preferences_box->details->category_view,
+		 0, "", gtk_cell_renderer_text_new (),
+		 "text", CATEGORY_COLUMN,
+		 NULL);
 	gtk_tree_view_set_headers_visible (preferences_box->details->category_view, FALSE);
 	gtk_tree_view_columns_autosize (preferences_box->details->category_view);
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (preferences_box->details->category_view),
@@ -581,7 +578,7 @@ eel_preferences_dialog_new (const char *title,
 	g_return_val_if_fail (title != NULL, NULL);
 	
 	dialog = gtk_dialog_new_with_buttons (title, NULL, 0,
-					      GTK_STOCK_OK, GTK_RESPONSE_OK,
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
 					      NULL);
 
 	/* Setup the dialog */
